package com.zy.bms.controller.pc;

import com.zy.bms.common.ServerResponse;
import com.zy.bms.common.controller.BaseController;
import com.zy.bms.common.io.pc.AdminIO;
import com.zy.bms.model.Admin;
import com.zy.bms.common.redis.SessionManager;
import com.zy.bms.service.AdminService;
import com.zy.bms.utils.MD5Util;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 管理员Controller
 *
 * @author yang xiao kun
 * create on 2021/2/24
 */
@RestController
@RequestMapping("bms/api/pc/admin")
public class AdminController extends BaseController {

    @Resource
    private AdminService adminService;

    @Resource
    private SessionManager sessionManager;

    /**
     * 登录
     */
    @PostMapping("login.do")
    public ServerResponse login(String username, String password) {
        Admin admin = adminService.getByUsernameOrPhone(username);
        if (admin == null) return ServerResponse.createByWarning("用户不存在");
        //MD5密码
        password = MD5Util.MD5Encode(password, admin.getSalt());
        if (!admin.getPassword().equals(password)) return ServerResponse.createByWarning("密码错误");
        // 返回 token 和 昵称
        Map<String, String> result = new HashMap<>();
        result.put("token", sessionManager.generateToken(admin));
        result.put("nickname", admin.getNickname());
        return ServerResponse.createBySuccess(result);
    }

    /**
     * 添加用户
     */
    @PostMapping("save.do")
    public ServerResponse save(Admin admin) {
        Admin current = sessionManager.getUser(getToken());
        if (current == null || current.getRole() != 1) return ServerResponse.createByWarning("无权限");
        adminService.saveAdmin(admin);
        return ServerResponse.createBySuccess();
    }

    /**
     * 禁用
     */
    @PostMapping("forbidden.do")
    public ServerResponse forbidden(Integer id) {
        adminService.updateStatus(id, 0);
        return ServerResponse.createBySuccess();
    }

    /**
     * 启用
     */
    @PostMapping("permit.do")
    public ServerResponse permit(Integer id) {
        adminService.updateStatus(id, 1);
        return ServerResponse.createBySuccess();
    }

    /**
     * 分页查询管理员列表
     */
    @PostMapping("listPage.do")
    public ServerResponse listPage(AdminIO io) {
        return ServerResponse.createBySuccess(adminService.listPage(io));
    }

    /**
     * token 验证
     */
    @GetMapping("verify.do")
    public ServerResponse verify() {
        return ServerResponse.createBySuccess();
    }
}
